#!/usr/bin/env python
# Created by "Thieu" at 22:23, 19/03/2023 ----------%                                                                               
#       Email: nguyenthieu2102@gmail.com            %                                                    
#       Github: https://github.com/thieu1995        %                         
# --------------------------------------------------%

def english(name="Daniel", show=True):
    if show:
        print(f"Hello: {name}")
    return name


def vietnamese(name="Tien", show=True):
    if show:
        print(f"Xin chao: {name}")
    return name
